==> generator-ng-poly-0.12.4.tgz: package/generators/route/index.js <==
'use strict';

require('babel-polyfill');

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _genBase = require('../genBase');

var _genBase2 = _interopRequireDefault(_genBase);

var _ngAddDep = require('ng-add-dep');

var _ngAddDep2 = _interopRequireDefault(_ngAddDep);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _pify = require('pify');

var _pify2 = _interopRequireDefault(_pify);

var _utils = require('../utils');

var _utils2 = _interopRequireDefault(_utils);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = _genBase2.default.extend({
  prompting: function prompting() {
    return regeneratorRuntime.async(function prompting$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return regeneratorRuntime.awrap(this.askForModuleName({ url: true, templateUrl: true }));

          case 2:

            // convert backslashes to forwardslashes for Windows
            if (this.templateUrl) {
              this.templateUrl = this.templateUrl.replace('\\', '/');
            }

          case 3:
          case 'end':
            return _context.stop();
        }
      }
    }, null, this);
  },
  writing: function writing() {
    var done, config, dependency, newRouteConfig, newState, wipPath, modulePath, routesPath;
    return regeneratorRuntime.async(function writing$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            done = this.async();
            _context2.next = 3;
            return regeneratorRuntime.awrap(this.getConfig());

          case 3:
            config = _context2.sent;
            dependency = config.ngRoute ? 'ngRoute' : 'ui.router';
            newRouteConfig = {
              appScript: config.appScript,
              controllerAs: config.controllerAs,
              skipController: config.skipController,
              passFunc: config.passFunc,
              ngRoute: config.ngRoute
            };

            // move this logic to utils-route

            config.url = this.url;
            config.lowerCamel = _utils2.default.lowerCamel(this.name.replace('.', '-'));
            config.hyphenName = _utils2.default.hyphenName(this.name.replace('.', '-'));
            config.ctrlName = _utils2.default.ctrlName(this.name.replace('.', '-'));
            config.humanName = _utils2.default.humanName(this.name.replace('.', '-'));

            newState = {
              name: this.name,
              module: this.module,
              url: this.url,
              lowerCamel: config.lowerCamel,
              hyphenName: config.hyphenName,
              ctrlName: config.ctrlName,
              templateUrl: this.templateUrl
            };

            // create module path minus extension
            // if modulePath is empty file name is app

            wipPath = _path2.default.join(this.config.path, '..', config.appDir, config.modulePath, config.modulePath === '' ? 'app' : _utils2.default.hyphenName(config.moduleName));

            // get name-module.{coffee,js,ts}

            _context2.next = 15;
            return regeneratorRuntime.awrap(_utils2.default.findModuleFile(wipPath));

          case 15:
            modulePath = _context2.sent;
            _context2.t0 = regeneratorRuntime;
            _context2.t1 = modulePath;
            _context2.next = 20;
            return regeneratorRuntime.awrap((0, _pify2.default)(_fs2.default.readFile)(modulePath, 'utf8'));

          case 20:
            _context2.t2 = _context2.sent;
            _context2.t3 = dependency;
            _context2.t4 = (0, _ngAddDep2.default)(_context2.t2, _context2.t3);
            _context2.t5 = (0, _pify2.default)(_fs2.default.writeFile)(_context2.t1, _context2.t4);
            _context2.next = 26;
            return _context2.t0.awrap.call(_context2.t0, _context2.t5);

          case 26:
            _context2.next = 28;
            return regeneratorRuntime.awrap(_utils2.default.findRoutesFile(wipPath));

          case 28:
            routesPath = _context2.sent;
            _context2.t6 = regeneratorRuntime;
            _context2.t7 = routesPath;
            _context2.t8 = _utils2.default;
            _context2.next = 34;
            return regeneratorRuntime.awrap((0, _pify2.default)(_fs2.default.readFile)(routesPath, 'utf8'));

          case 34:
            _context2.t9 = _context2.sent;
            _context2.t10 = newState;
            _context2.t11 = newRouteConfig;
            _context2.t12 = _context2.t8.addRoute.call(_context2.t8, _context2.t9, _context2.t10, _context2.t11);
            _context2.t13 = (0, _pify2.default)(_fs2.default.writeFile)(_context2.t7, _context2.t12);
            _context2.next = 41;
            return _context2.t6.awrap.call(_context2.t6, _context2.t13);

          case 41:

            this.copyE2e(config);

            if (!config.skipController) {
              // call controller subgenerator
              this.composeWith('ng-poly:controller', {
                args: [this.name.replace('.', '-')],
                options: {
                  module: this.module,
                  structure: this.options.structure,
                  markup: this.options.markup,
                  'app-script': this.options['app-script'],
                  'controller-as': this.options['controller-as'],
                  classes: this.options.classes,
                  'pass-func': this.options['pass-func'],
                  'named-func': this.options['named-func'],
                  'test-script': this.options['test-script'],
                  'test-dir': this.options['test-dir'],
                  style: this.options.style
                }
              }, {
                local: require.resolve('../controller'),
                link: 'strong'
              });
            }

            // call view subgenerator
            this.composeWith('ng-poly:view', {
              args: [_path2.default.basename(this.templateUrl)],
              options: {
                module: this.module,
                structure: this.options.structure,
                markup: this.options.markup,
                'app-script': this.options['app-script'],
                'controller-as': this.options['controller-as'],
                'pass-func': this.options['pass-func'],
                'named-func': this.options['named-func'],
                'test-script': this.options['test-script'],
                'test-dir': this.options['test-dir'],
                'ng-route': this.options['ng-route'],
                style: this.options.style
              }
            }, {
              local: require.resolve('../view'),
              link: 'strong'
            });

            done();

          case 45:
          case 'end':
            return _context2.stop();
        }
      }
    }, null, this);
  }
});

==> generator-ng-poly-0.13.0.tgz: package/generators/route/index.js <==
'use strict';

require('babel-polyfill');

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _genBase = require('../genBase');

var _genBase2 = _interopRequireDefault(_genBase);

var _ngAddDep = require('ng-add-dep');

var _ngAddDep2 = _interopRequireDefault(_ngAddDep);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _pify = require('pify');

var _pify2 = _interopRequireDefault(_pify);

var _utils = require('../utils');

var _utils2 = _interopRequireDefault(_utils);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = _genBase2.default.extend({
  prompting: function prompting() {
    return regeneratorRuntime.async(function prompting$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return regeneratorRuntime.awrap(this.askForModuleName({ url: true, templateUrl: true }));

          case 2:

            // convert backslashes to forwardslashes for Windows
            if (this.templateUrl) {
              this.templateUrl = this.templateUrl.replace('\\', '/');
            }

          case 3:
          case 'end':
            return _context.stop();
        }
      }
    }, null, this);
  },
  writing: function writing() {
    var config, dependency, newRouteConfig, newState, wipPath, modulePath, routesPath;
    return regeneratorRuntime.async(function writing$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.next = 2;
            return regeneratorRuntime.awrap(this.getConfig());

          case 2:
            config = _context2.sent;
            dependency = config.ngRoute ? 'ngRoute' : 'ui.router';
            newRouteConfig = {
              appScript: config.appScript,
              controllerAs: config.controllerAs,
              skipController: config.skipController,
              passFunc: config.passFunc,
              ngRoute: config.ngRoute
            };

            // move this logic to utils-route

            config.url = this.url;
            config.lowerCamel = _utils2.default.lowerCamel(this.name.replace('.', '-'));
            config.hyphenName = _utils2.default.hyphenName(this.name.replace('.', '-'));
            config.ctrlName = _utils2.default.ctrlName(this.name.replace('.', '-'));
            config.humanName = _utils2.default.humanName(this.name.replace('.', '-'));

            newState = {
              name: this.name,
              module: this.module,
              url: this.url,
              lowerCamel: config.lowerCamel,
              hyphenName: config.hyphenName,
              ctrlName: config.ctrlName,
              templateUrl: this.templateUrl
            };

            // create module path minus extension
            // if modulePath is empty file name is app

            wipPath = _path2.default.join(this.config.path, '..', config.appDir, config.modulePath, config.modulePath === '' ? 'app' : _utils2.default.hyphenName(config.moduleName));

            // get name-module.{coffee,js,ts}

            _context2.next = 14;
            return regeneratorRuntime.awrap(_utils2.default.findModuleFile(wipPath));

          case 14:
            modulePath = _context2.sent;
            _context2.t0 = regeneratorRuntime;
            _context2.t1 = modulePath;
            _context2.next = 19;
            return regeneratorRuntime.awrap((0, _pify2.default)(_fs2.default.readFile)(modulePath, 'utf8'));

          case 19:
            _context2.t2 = _context2.sent;
            _context2.t3 = dependency;
            _context2.t4 = (0, _ngAddDep2.default)(_context2.t2, _context2.t3);
            _context2.t5 = (0, _pify2.default)(_fs2.default.writeFile)(_context2.t1, _context2.t4);
            _context2.next = 25;
            return _context2.t0.awrap.call(_context2.t0, _context2.t5);

          case 25:
            _context2.next = 27;
            return regeneratorRuntime.awrap(_utils2.default.findRoutesFile(wipPath));

          case 27:
            routesPath = _context2.sent;
            _context2.t6 = regeneratorRuntime;
            _context2.t7 = routesPath;
            _context2.t8 = _utils2.default;
            _context2.next = 33;
            return regeneratorRuntime.awrap((0, _pify2.default)(_fs2.default.readFile)(routesPath, 'utf8'));

          case 33:
            _context2.t9 = _context2.sent;
            _context2.t10 = newState;
            _context2.t11 = newRouteConfig;
            _context2.t12 = _context2.t8.addRoute.call(_context2.t8, _context2.t9, _context2.t10, _context2.t11);
            _context2.t13 = (0, _pify2.default)(_fs2.default.writeFile)(_context2.t7, _context2.t12);
            _context2.next = 40;
            return _context2.t6.awrap.call(_context2.t6, _context2.t13);

          case 40:

            this.copyE2e(config);

            if (!config.skipController) {
              // call controller subgenerator
              this.composeWith('ng-poly:controller', {
                args: [this.name.replace('.', '-')],
                options: {
                  module: this.module,
                  structure: this.options.structure,
                  markup: this.options.markup,
                  'app-script': this.options['app-script'],
                  'controller-as': this.options['controller-as'],
                  classes: this.options.classes,
                  'pass-func': this.options['pass-func'],
                  'named-func': this.options['named-func'],
                  'test-script': this.options['test-script'],
                  'test-dir': this.options['test-dir'],
                  style: this.options.style
                }
              }, {
                local: require.resolve('../controller'),
                link: 'strong'
              });
            }

            // call view subgenerator
            this.composeWith('ng-poly:view', {
              args: [_path2.default.basename(this.templateUrl)],
              options: {
                module: this.module,
                structure: this.options.structure,
                markup: this.options.markup,
                'app-script': this.options['app-script'],
                'controller-as': this.options['controller-as'],
                'pass-func': this.options['pass-func'],
                'named-func': this.options['named-func'],
                'test-script': this.options['test-script'],
                'test-dir': this.options['test-dir'],
                'ng-route': this.options['ng-route'],
                style: this.options.style
              }
            }, {
              local: require.resolve('../view'),
              link: 'strong'
            });

          case 43:
          case 'end':
            return _context2.stop();
        }
      }
    }, null, this);
  }
});
